## 4.0.8 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 4.0.7 (2022-01-07)

Update pyright (#6840)

## 4.0.5 (2021-12-25)

Fixes for third-party mock package (#6685)

Removed a few unused private classes and methods. They can be re-added if a user reports them missing.

## 4.0.4 (2021-11-26)

Add mypy error codes to '# type: ignore' comments (#6379)

## 4.0.3 (2021-10-15)

Use lowercase tuple where possible (#6170)

## 4.0.2 (2021-10-12)

Add star to all non-0.1 versions (#6146)

